/*
 * XdccDownloader - ChannelJoined.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;

/**
 * Abstract base class for all events that happen on a channel.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public abstract class AbstractChannelEvent extends AbstractConnectionEvent {

	/** The channel this event occured on. */
	private final String channel;

	/**
	 * Creates a new abstract channel event.
	 *
	 * @param connection
	 * 		The connection this event occured on
	 * @param channel
	 * 		The channel this event occured on
	 */
	protected AbstractChannelEvent(Connection connection, String channel) {
		super(connection);
		this.channel = channel;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the channel this event occured on.
	 *
	 * @return The channel this event occured on
	 */
	public String channel() {
		return channel;
	}

}
