/*
 * XdccDownloader - AbstractReplyEvent.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.irc.Reply;

/**
 * Abstract base class for all events based on {@link Reply}s (and thus very low
 * level). Examples would be e.g. nick changing messages, mode changes, private
 * messages, and other single/global events that do not carry state.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public abstract class AbstractReplyEvent extends AbstractConnectionEvent {

	/** The reply that caused this event. */
	private final Reply reply;

	/**
	 * Creates a new abstract reply event.
	 *
	 * @param connection
	 * 		The connection the event occured on
	 * @param reply
	 * 		The reply that caused this event
	 */
	protected AbstractReplyEvent(Connection connection, Reply reply) {
		super(connection);
		this.reply = reply;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the reply that caused this event.
	 *
	 * @return The reply that caused this event
	 */
	public Reply reply() {
		return reply;
	}

}
