/*
 * XdccDownloader - DisconnectCommand.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.ui.stdin;

import static java.util.Arrays.asList;

import java.io.IOException;
import java.io.Writer;
import java.util.Collection;
import java.util.List;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.xdcc.core.Core;

import com.google.common.primitives.Ints;

/**
 * Command that will disconnect a {@link Connection}.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 * @see State#getLastConnections()
 */
public class DisconnectCommand implements Command {

	/** The core to operate on. */
	private final Core core;

	/**
	 * Creates a new disconnect command.
	 *
	 * @param core
	 * 		The core to operate on
	 */
	public DisconnectCommand(Core core) {
		this.core = core;
	}

	//
	// COMMAND METHODS
	//

	@Override
	public String getName() {
		return "disconnect";
	}

	@Override
	public Collection<String> getAliases() {
		return asList("close");
	}

	@Override
	public State execute(State state, List<String> parameters, Writer outputWriter) throws IOException {
		if ((parameters.isEmpty() || ("all".equals(parameters.get(0))))) {
			for (Connection connection : state.getLastConnections()) {
				core.closeConnection(connection);
			}
		} else {
			Integer index = Ints.tryParse(parameters.get(0));
			if ((index != null) && (index < state.getLastConnections().size())) {
				core.closeConnection(state.getLastConnections().get(index));
			}
		}
		return state;
	}

}
