/*
 * XdccDownloader - ListConnectionsCommand.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.ui.stdin;

import static com.google.common.collect.Lists.newArrayList;
import static java.util.Collections.emptyList;
import static net.pterodactylus.xdcc.ui.stdin.CommandReader.f;

import java.io.IOException;
import java.io.Writer;
import java.util.Collection;
import java.util.List;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.xdcc.core.Core;

/**
 * Command that will list all current connectios.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ListConnectionsCommand implements Command {

	/** The core to operate on. */
	private final Core core;

	/**
	 * Creates a new list connections command.
	 *
	 * @param core
	 * 		The core to operate on
	 */
	public ListConnectionsCommand(Core core) {
		this.core = core;
	}

	//
	// COMMAND METHODS
	//

	@Override
	public String getName() {
		return "connections";
	}

	@Override
	public Collection<String> getAliases() {
		return emptyList();
	}

	@Override
	public State execute(State state, List<String> parameters, Writer outputWriter) throws IOException {
		List<Connection> lastConnections = newArrayList();
		int counter = 0;
		for (Connection connection : core.connections()) {
			lastConnections.add(connection);
			outputWriter.write(String.format("[%d] %s:%d, %s/s\n", counter++, connection.hostname(), connection.port(), f(connection.getInputRate())));
		}
		outputWriter.write("End of connections.\n");
		return state.setLastConnections(lastConnections);
	}

}
